@@ -23,7 +23,7 @@
 
 #include <btrfsutil.h>
 
-#include "ctree.h"
+#include "kernel-shared/ctree.h"
 #include "cmds/commands.h"
 #include "common/utils.h"
 #include "props.h"
@@ -183,7 +183,7 @@ const struct prop_handler prop_handlers[] = {
 	},
 	{
 		.name = "compression",
-		.desc = "compression algorighm for the file or directory",
+		.desc = "compression algorithm for the file or directory",
 		.read_only = 0,
 	 	.types = prop_object_inode, prop_compression
 	},
